==> ask-sdk-model-1.9.0.tar.gz: ask-sdk-model-1.9.0/ask_sdk_model/services/gadget_controller/animation_step.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class AnimationStep(object):
    """

    :param duration_ms: The duration in milliseconds to render this step. 
    :type duration_ms: (optional) int
    :param color: The color to render specified in RGB hexadecimal values. There are a number of Node.js libraries available for working with color. 
    :type color: (optional) str
    :param blend: A boolean that indicates whether to interpolate from the previous color into this one over the course of this directive&#39;s durationMs.
    :type blend: (optional) bool

    """
    deserialized_types = {
        'duration_ms': 'int',
        'color': 'str',
        'blend': 'bool'
    }

    attribute_map = {
        'duration_ms': 'durationMs',
        'color': 'color',
        'blend': 'blend'
    }

    def __init__(self, duration_ms=None, color=None, blend=None):
        # type: (Optional[int], Optional[str], Optional[bool]) -> None
        """

        :param duration_ms: The duration in milliseconds to render this step. 
        :type duration_ms: (optional) int
        :param color: The color to render specified in RGB hexadecimal values. There are a number of Node.js libraries available for working with color. 
        :type color: (optional) str
        :param blend: A boolean that indicates whether to interpolate from the previous color into this one over the course of this directive&#39;s durationMs.
        :type blend: (optional) bool
        """
        self.__discriminator_value = None

        self.duration_ms = duration_ms
        self.color = color
        self.blend = blend

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, AnimationStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask-sdk-model-1.10.2.tar.gz: ask-sdk-model-1.10.2/ask_sdk_model/services/gadget_controller/animation_step.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class AnimationStep(object):
    """

    :param duration_ms: The duration in milliseconds to render this step. 
    :type duration_ms: (optional) int
    :param color: The color to render specified in RGB hexadecimal values. There are a number of Node.js libraries available for working with color. 
    :type color: (optional) str
    :param blend: A boolean that indicates whether to interpolate from the previous color into this one over the course of this directive&#39;s durationMs.
    :type blend: (optional) bool

    """
    deserialized_types = {
        'duration_ms': 'int',
        'color': 'str',
        'blend': 'bool'
    }  # type: Dict

    attribute_map = {
        'duration_ms': 'durationMs',
        'color': 'color',
        'blend': 'blend'
    }  # type: Dict

    def __init__(self, duration_ms=None, color=None, blend=None):
        # type: (Optional[int], Optional[str], Optional[bool]) -> None
        """

        :param duration_ms: The duration in milliseconds to render this step. 
        :type duration_ms: (optional) int
        :param color: The color to render specified in RGB hexadecimal values. There are a number of Node.js libraries available for working with color. 
        :type color: (optional) str
        :param blend: A boolean that indicates whether to interpolate from the previous color into this one over the course of this directive&#39;s durationMs.
        :type blend: (optional) bool
        """
        self.__discriminator_value = None  # type: str

        self.duration_ms = duration_ms
        self.color = color
        self.blend = blend

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, AnimationStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
